wagtail-tags-block
==================

A Wagtail block for storing tags. Please bear with us while we prepare more detailed documentation.

Compatibility
-------------

`wagtail-tags-block`' major.minor version number indicates the Wagtail release it is compatible with. Currently this is Wagtail 4.1.x

Installation
------------

1. Install using `pip`:
  ```shell
  pip install wagtail-tags-block
  ```
2. Add
   `wagtail_tags_block` to your `INSTALLED_APPS` setting:
   ```python
   INSTALLED_APPS = [
     # ...
     'wagtail_tags_block'
     # ...
   ]
   ```
